Simulates a random cluster nearest-neighbour neutral landscape.
Usage
nlm_randomcluster(
ncol,
nrow,
resolution = 1,
p,
ai = c(0.5, 0.5),
neighbourhood = 4,
user_seed = NULL,
rescale = TRUE
)Arguments
- ncol
[
integer(1)]
Number of columns forming the raster.- nrow
[
integer(1)]
Number of rows forming the raster.- resolution
[
numerical(1)]
Resolution of the raster.- p
[
numerical(1)]
Defines the proportion of elements randomly selected to form clusters.- ai
Vector with the cluster type distribution (percentages of occupancy). This directly controls the number of types via the given length.
- neighbourhood
[
numerical(1)]
Clusters are defined using a set of neighbourhood structures, 4 (Rook's or von Neumann neighbourhood) (default), 8 (Queen's or Moore neighbourhood).- user_seed
[
numerical(1)]
Set random seed for the simulation.- rescale
[
logical(1)]
IfTRUE(default), the values are rescaled between 0-1.
Details
This is a direct implementation of steps A - D of the modified random clusters algorithm by Saura & Martínez-Millán (2000), which creates naturalistic patchy patterns.